# Generated by default/object.tt
package Paws::CloudFront::ForwardedValues;
  use Moose;
  has Cookies => (is => 'ro', isa => 'Paws::CloudFront::CookiePreference', required => 1);
  has Headers => (is => 'ro', isa => 'Paws::CloudFront::Headers');
  has QueryString => (is => 'ro', isa => 'Bool', required => 1);
  has QueryStringCacheKeys => (is => 'ro', isa => 'Paws::CloudFront::QueryStringCacheKeys');

1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudFront::ForwardedValues

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::CloudFront::ForwardedValues object:

  $service_obj->Method(Att1 => { Cookies => $value, ..., QueryStringCacheKeys => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::CloudFront::ForwardedValues object:

  $result = $service_obj->Method(...);
  $result->Att1->Cookies

=head1 DESCRIPTION

This field is deprecated. We recommend that you use a cache policy or
an origin request policy instead of this field.

If you want to include values in the cache key, use a cache policy. For
more information, see Creating cache policies
(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy)
in the I<Amazon CloudFront Developer Guide>.

If you want to send values to the origin but not include them in the
cache key, use an origin request policy. For more information, see
Creating origin request policies
(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy)
in the I<Amazon CloudFront Developer Guide>.

A complex type that specifies how CloudFront handles query strings,
cookies, and HTTP headers.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Cookies => L<Paws::CloudFront::CookiePreference>

This field is deprecated. We recommend that you use a cache policy or
an origin request policy instead of this field.

If you want to include cookies in the cache key, use a cache policy.
For more information, see Creating cache policies
(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy)
in the I<Amazon CloudFront Developer Guide>.

If you want to send cookies to the origin but not include them in the
cache key, use an origin request policy. For more information, see
Creating origin request policies
(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy)
in the I<Amazon CloudFront Developer Guide>.

A complex type that specifies whether you want CloudFront to forward
cookies to the origin and, if so, which ones. For more information
about forwarding cookies to the origin, see How CloudFront Forwards,
Caches, and Logs Cookies
(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Cookies.html)
in the I<Amazon CloudFront Developer Guide>.


=head2 Headers => L<Paws::CloudFront::Headers>

This field is deprecated. We recommend that you use a cache policy or
an origin request policy instead of this field.

If you want to include headers in the cache key, use a cache policy.
For more information, see Creating cache policies
(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy)
in the I<Amazon CloudFront Developer Guide>.

If you want to send headers to the origin but not include them in the
cache key, use an origin request policy. For more information, see
Creating origin request policies
(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy)
in the I<Amazon CloudFront Developer Guide>.

A complex type that specifies the C<Headers>, if any, that you want
CloudFront to forward to the origin for this cache behavior
(whitelisted headers). For the headers that you specify, CloudFront
also caches separate versions of a specified object that is based on
the header values in viewer requests.

For more information, see Caching Content Based on Request Headers
(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/header-caching.html)
in the I<Amazon CloudFront Developer Guide>.


=head2 B<REQUIRED> QueryString => Bool

This field is deprecated. We recommend that you use a cache policy or
an origin request policy instead of this field.

If you want to include query strings in the cache key, use a cache
policy. For more information, see Creating cache policies
(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy)
in the I<Amazon CloudFront Developer Guide>.

If you want to send query strings to the origin but not include them in
the cache key, use an origin request policy. For more information, see
Creating origin request policies
(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy)
in the I<Amazon CloudFront Developer Guide>.

Indicates whether you want CloudFront to forward query strings to the
origin that is associated with this cache behavior and cache based on
the query string parameters. CloudFront behavior depends on the value
of C<QueryString> and on the values that you specify for
C<QueryStringCacheKeys>, if any:

If you specify true for C<QueryString> and you don't specify any values
for C<QueryStringCacheKeys>, CloudFront forwards all query string
parameters to the origin and caches based on all query string
parameters. Depending on how many query string parameters and values
you have, this can adversely affect performance because CloudFront must
forward more requests to the origin.

If you specify true for C<QueryString> and you specify one or more
values for C<QueryStringCacheKeys>, CloudFront forwards all query
string parameters to the origin, but it only caches based on the query
string parameters that you specify.

If you specify false for C<QueryString>, CloudFront doesn't forward any
query string parameters to the origin, and doesn't cache based on query
string parameters.

For more information, see Configuring CloudFront to Cache Based on
Query String Parameters
(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/QueryStringParameters.html)
in the I<Amazon CloudFront Developer Guide>.


=head2 QueryStringCacheKeys => L<Paws::CloudFront::QueryStringCacheKeys>

This field is deprecated. We recommend that you use a cache policy or
an origin request policy instead of this field.

If you want to include query strings in the cache key, use a cache
policy. For more information, see Creating cache policies
(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy)
in the I<Amazon CloudFront Developer Guide>.

If you want to send query strings to the origin but not include them in
the cache key, use an origin request policy. For more information, see
Creating origin request policies
(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy)
in the I<Amazon CloudFront Developer Guide>.

A complex type that contains information about the query string
parameters that you want CloudFront to use for caching for this cache
behavior.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::CloudFront>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

