
package Paws::Glue::GetClassifiers;
  use Moose;
  has MaxResults => (is => 'ro', isa => 'Int');
  has NextToken => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetClassifiers');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Glue::GetClassifiersResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::GetClassifiers - Arguments for method GetClassifiers on L<Paws::Glue>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetClassifiers on the
L<AWS Glue|Paws::Glue> service. Use the attributes of this class
as arguments to method GetClassifiers.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetClassifiers.

=head1 SYNOPSIS

    my $glue = Paws->service('Glue');
    my $GetClassifiersResponse = $glue->GetClassifiers(
      MaxResults => 1,            # OPTIONAL
      NextToken  => 'MyToken',    # OPTIONAL
    );

    # Results:
    my $Classifiers = $GetClassifiersResponse->Classifiers;
    my $NextToken   = $GetClassifiersResponse->NextToken;

    # Returns a L<Paws::Glue::GetClassifiersResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/glue/GetClassifiers>

=head1 ATTRIBUTES


=head2 MaxResults => Int

The size of the list to return (optional).



=head2 NextToken => Str

An optional continuation token.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetClassifiers in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

