
package Paws::Greengrass::GetDeviceDefinitionVersion;
  use Moose;
  has DeviceDefinitionId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'DeviceDefinitionId', required => 1);
  has DeviceDefinitionVersionId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'DeviceDefinitionVersionId', required => 1);
  has NextToken => (is => 'ro', isa => 'Str', traits => ['ParamInQuery'], query_name => 'NextToken');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetDeviceDefinitionVersion');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/greengrass/definition/devices/{DeviceDefinitionId}/versions/{DeviceDefinitionVersionId}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Greengrass::GetDeviceDefinitionVersionResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Greengrass::GetDeviceDefinitionVersion - Arguments for method GetDeviceDefinitionVersion on L<Paws::Greengrass>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetDeviceDefinitionVersion on the
L<AWS Greengrass|Paws::Greengrass> service. Use the attributes of this class
as arguments to method GetDeviceDefinitionVersion.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetDeviceDefinitionVersion.

=head1 SYNOPSIS

    my $greengrass = Paws->service('Greengrass');
    my $GetDeviceDefinitionVersionResponse =
      $greengrass->GetDeviceDefinitionVersion(
      DeviceDefinitionId        => 'My__string',
      DeviceDefinitionVersionId => 'My__string',
      NextToken                 => 'My__string',    # OPTIONAL
      );

    # Results:
    my $Arn = $GetDeviceDefinitionVersionResponse->Arn;
    my $CreationTimestamp =
      $GetDeviceDefinitionVersionResponse->CreationTimestamp;
    my $Definition = $GetDeviceDefinitionVersionResponse->Definition;
    my $Id         = $GetDeviceDefinitionVersionResponse->Id;
    my $NextToken  = $GetDeviceDefinitionVersionResponse->NextToken;
    my $Version    = $GetDeviceDefinitionVersionResponse->Version;

    # Returns a L<Paws::Greengrass::GetDeviceDefinitionVersionResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/greengrass/GetDeviceDefinitionVersion>

=head1 ATTRIBUTES


=head2 B<REQUIRED> DeviceDefinitionId => Str

The ID of the device definition.



=head2 B<REQUIRED> DeviceDefinitionVersionId => Str

The ID of the device definition version. This value maps to the
''Version'' property of the corresponding ''VersionInformation''
object, which is returned by ''ListDeviceDefinitionVersions'' requests.
If the version is the last one that was associated with a device
definition, the value also maps to the ''LatestVersion'' property of
the corresponding ''DefinitionInformation'' object.



=head2 NextToken => Str

The token for the next set of results, or ''null'' if there are no
additional results.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetDeviceDefinitionVersion in L<Paws::Greengrass>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

