
package Paws::IoTWireless::GetWirelessGatewayStatistics;
  use Moose;
  has WirelessGatewayId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'Id', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetWirelessGatewayStatistics');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/wireless-gateways/{Id}/statistics');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IoTWireless::GetWirelessGatewayStatisticsResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IoTWireless::GetWirelessGatewayStatistics - Arguments for method GetWirelessGatewayStatistics on L<Paws::IoTWireless>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetWirelessGatewayStatistics on the
L<AWS IoT Wireless|Paws::IoTWireless> service. Use the attributes of this class
as arguments to method GetWirelessGatewayStatistics.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetWirelessGatewayStatistics.

=head1 SYNOPSIS

    my $api.iotwireless = Paws->service('IoTWireless');
    my $GetWirelessGatewayStatisticsResponse =
      $api . iotwireless->GetWirelessGatewayStatistics(
      WirelessGatewayId => 'MyWirelessGatewayId',

      );

    # Results:
    my $ConnectionStatus =
      $GetWirelessGatewayStatisticsResponse->ConnectionStatus;
    my $LastUplinkReceivedAt =
      $GetWirelessGatewayStatisticsResponse->LastUplinkReceivedAt;
    my $WirelessGatewayId =
      $GetWirelessGatewayStatisticsResponse->WirelessGatewayId;

  # Returns a L<Paws::IoTWireless::GetWirelessGatewayStatisticsResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/api.iotwireless/GetWirelessGatewayStatistics>

=head1 ATTRIBUTES


=head2 B<REQUIRED> WirelessGatewayId => Str

The ID of the wireless gateway for which to get the data.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetWirelessGatewayStatistics in L<Paws::IoTWireless>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

