# Generated by default/object.tt
package Paws::KMS::KeyMetadata;
  use Moose;
  has Arn => (is => 'ro', isa => 'Str');
  has AWSAccountId => (is => 'ro', isa => 'Str');
  has CloudHsmClusterId => (is => 'ro', isa => 'Str');
  has CreationDate => (is => 'ro', isa => 'Str');
  has CustomerMasterKeySpec => (is => 'ro', isa => 'Str');
  has CustomKeyStoreId => (is => 'ro', isa => 'Str');
  has DeletionDate => (is => 'ro', isa => 'Str');
  has Description => (is => 'ro', isa => 'Str');
  has Enabled => (is => 'ro', isa => 'Bool');
  has EncryptionAlgorithms => (is => 'ro', isa => 'ArrayRef[Str|Undef]');
  has ExpirationModel => (is => 'ro', isa => 'Str');
  has KeyId => (is => 'ro', isa => 'Str', required => 1);
  has KeyManager => (is => 'ro', isa => 'Str');
  has KeyState => (is => 'ro', isa => 'Str');
  has KeyUsage => (is => 'ro', isa => 'Str');
  has MultiRegion => (is => 'ro', isa => 'Bool');
  has MultiRegionConfiguration => (is => 'ro', isa => 'Paws::KMS::MultiRegionConfiguration');
  has Origin => (is => 'ro', isa => 'Str');
  has PendingDeletionWindowInDays => (is => 'ro', isa => 'Int');
  has SigningAlgorithms => (is => 'ro', isa => 'ArrayRef[Str|Undef]');
  has ValidTo => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::KMS::KeyMetadata

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::KMS::KeyMetadata object:

  $service_obj->Method(Att1 => { Arn => $value, ..., ValidTo => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::KMS::KeyMetadata object:

  $result = $service_obj->Method(...);
  $result->Att1->Arn

=head1 DESCRIPTION

Contains metadata about a customer master key (CMK).

This data type is used as a response element for the CreateKey and
DescribeKey operations.

=head1 ATTRIBUTES


=head2 Arn => Str

The Amazon Resource Name (ARN) of the CMK. For examples, see AWS Key
Management Service (AWS KMS)
(https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html#arn-syntax-kms)
in the Example ARNs section of the I<AWS General Reference>.


=head2 AWSAccountId => Str

The twelve-digit account ID of the AWS account that owns the CMK.


=head2 CloudHsmClusterId => Str

The cluster ID of the AWS CloudHSM cluster that contains the key
material for the CMK. When you create a CMK in a custom key store
(https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html),
AWS KMS creates the key material for the CMK in the associated AWS
CloudHSM cluster. This value is present only when the CMK is created in
a custom key store.


=head2 CreationDate => Str

The date and time when the CMK was created.


=head2 CustomerMasterKeySpec => Str

Describes the type of key material in the CMK.


=head2 CustomKeyStoreId => Str

A unique identifier for the custom key store
(https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html)
that contains the CMK. This value is present only when the CMK is
created in a custom key store.


=head2 DeletionDate => Str

The date and time after which AWS KMS deletes this CMK. This value is
present only when the CMK is scheduled for deletion, that is, when its
C<KeyState> is C<PendingDeletion>.

When the primary key in a multi-Region key is scheduled for deletion
but still has replica keys, its key state is C<PendingReplicaDeletion>
and the length of its waiting period is displayed in the
C<PendingDeletionWindowInDays> field.


=head2 Description => Str

The description of the CMK.


=head2 Enabled => Bool

Specifies whether the CMK is enabled. When C<KeyState> is C<Enabled>
this value is true, otherwise it is false.


=head2 EncryptionAlgorithms => ArrayRef[Str|Undef]

The encryption algorithms that the CMK supports. You cannot use the CMK
with other encryption algorithms within AWS KMS.

This value is present only when the C<KeyUsage> of the CMK is
C<ENCRYPT_DECRYPT>.


=head2 ExpirationModel => Str

Specifies whether the CMK's key material expires. This value is present
only when C<Origin> is C<EXTERNAL>, otherwise this value is omitted.


=head2 B<REQUIRED> KeyId => Str

The globally unique identifier for the CMK.


=head2 KeyManager => Str

The manager of the CMK. CMKs in your AWS account are either customer
managed or AWS managed. For more information about the difference, see
Customer Master Keys
(https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#master_keys)
in the I<AWS Key Management Service Developer Guide>.


=head2 KeyState => Str

The current status of the CMK.

For more information about how key state affects the use of a CMK, see
Key state: Effect on your CMK
(https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html)
in the I<AWS Key Management Service Developer Guide>.


=head2 KeyUsage => Str

The cryptographic operations
(https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#cryptographic-operations)
for which you can use the CMK.


=head2 MultiRegion => Bool

Indicates whether the CMK is a multi-Region (C<True>) or regional
(C<False>) key. This value is C<True> for multi-Region primary and
replica CMKs and C<False> for regional CMKs.

For more information about multi-Region keys, see Using multi-Region
keys
(https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-overview.html)
in the I<AWS Key Management Service Developer Guide>.


=head2 MultiRegionConfiguration => L<Paws::KMS::MultiRegionConfiguration>

Lists the primary and replica CMKs in same multi-Region CMK. This field
is present only when the value of the C<MultiRegion> field is C<True>.

For more information about any listed CMK, use the DescribeKey
operation.

=over

=item *

C<MultiRegionKeyType> indicates whether the CMK is a C<PRIMARY> or
C<REPLICA> key.

=item *

C<PrimaryKey> displays the key ARN and Region of the primary key. This
field displays the current CMK if it is the primary key.

=item *

C<ReplicaKeys> displays the key ARNs and Regions of all replica keys.
This field includes the current CMK if it is a replica key.

=back



=head2 Origin => Str

The source of the CMK's key material. When this value is C<AWS_KMS>,
AWS KMS created the key material. When this value is C<EXTERNAL>, the
key material was imported from your existing key management
infrastructure or the CMK lacks key material. When this value is
C<AWS_CLOUDHSM>, the key material was created in the AWS CloudHSM
cluster associated with a custom key store.


=head2 PendingDeletionWindowInDays => Int

The waiting period before the primary key in a multi-Region key is
deleted. This waiting period begins when the last of its replica keys
is deleted. This value is present only when the C<KeyState> of the CMK
is C<PendingReplicaDeletion>. That indicates that the CMK is the
primary key in a multi-Region key, it is scheduled for deletion, and it
still has existing replica keys.

When a regional CMK or a replica key in a multi-Region key is scheduled
for deletion, its deletion date is displayed in the C<DeletionDate>
field. However, when the primary key in a multi-Region key is scheduled
for deletion, its waiting period doesn't begin until all of its replica
keys are deleted. This value displays that waiting period. When the
last replica key in the multi-Region key is deleted, the C<KeyState> of
the scheduled primary key changes from C<PendingReplicaDeletion> to
C<PendingDeletion> and the deletion date appears in the C<DeletionDate>
field.


=head2 SigningAlgorithms => ArrayRef[Str|Undef]

The signing algorithms that the CMK supports. You cannot use the CMK
with other signing algorithms within AWS KMS.

This field appears only when the C<KeyUsage> of the CMK is
C<SIGN_VERIFY>.


=head2 ValidTo => Str

The time at which the imported key material expires. When the key
material expires, AWS KMS deletes the key material and the CMK becomes
unusable. This value is present only for CMKs whose C<Origin> is
C<EXTERNAL> and whose C<ExpirationModel> is C<KEY_MATERIAL_EXPIRES>,
otherwise this value is omitted.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::KMS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

