
package Paws::RDS::CreateDBInstance;
  use Moose;
  has AllocatedStorage => (is => 'ro', isa => 'Int');
  has AutoMinorVersionUpgrade => (is => 'ro', isa => 'Bool');
  has AvailabilityZone => (is => 'ro', isa => 'Str');
  has BackupRetentionPeriod => (is => 'ro', isa => 'Int');
  has CharacterSetName => (is => 'ro', isa => 'Str');
  has CopyTagsToSnapshot => (is => 'ro', isa => 'Bool');
  has DBClusterIdentifier => (is => 'ro', isa => 'Str');
  has DBInstanceClass => (is => 'ro', isa => 'Str', required => 1);
  has DBInstanceIdentifier => (is => 'ro', isa => 'Str', required => 1);
  has DBName => (is => 'ro', isa => 'Str');
  has DBParameterGroupName => (is => 'ro', isa => 'Str');
  has DBSecurityGroups => (is => 'ro', isa => 'ArrayRef[Str|Undef]');
  has DBSubnetGroupName => (is => 'ro', isa => 'Str');
  has DeletionProtection => (is => 'ro', isa => 'Bool');
  has Domain => (is => 'ro', isa => 'Str');
  has DomainIAMRoleName => (is => 'ro', isa => 'Str');
  has EnableCloudwatchLogsExports => (is => 'ro', isa => 'ArrayRef[Str|Undef]');
  has EnableCustomerOwnedIp => (is => 'ro', isa => 'Bool');
  has EnableIAMDatabaseAuthentication => (is => 'ro', isa => 'Bool');
  has EnablePerformanceInsights => (is => 'ro', isa => 'Bool');
  has Engine => (is => 'ro', isa => 'Str', required => 1);
  has EngineVersion => (is => 'ro', isa => 'Str');
  has Iops => (is => 'ro', isa => 'Int');
  has KmsKeyId => (is => 'ro', isa => 'Str');
  has LicenseModel => (is => 'ro', isa => 'Str');
  has MasterUsername => (is => 'ro', isa => 'Str');
  has MasterUserPassword => (is => 'ro', isa => 'Str');
  has MaxAllocatedStorage => (is => 'ro', isa => 'Int');
  has MonitoringInterval => (is => 'ro', isa => 'Int');
  has MonitoringRoleArn => (is => 'ro', isa => 'Str');
  has MultiAZ => (is => 'ro', isa => 'Bool');
  has NcharCharacterSetName => (is => 'ro', isa => 'Str');
  has OptionGroupName => (is => 'ro', isa => 'Str');
  has PerformanceInsightsKMSKeyId => (is => 'ro', isa => 'Str');
  has PerformanceInsightsRetentionPeriod => (is => 'ro', isa => 'Int');
  has Port => (is => 'ro', isa => 'Int');
  has PreferredBackupWindow => (is => 'ro', isa => 'Str');
  has PreferredMaintenanceWindow => (is => 'ro', isa => 'Str');
  has ProcessorFeatures => (is => 'ro', isa => 'ArrayRef[Paws::RDS::ProcessorFeature]');
  has PromotionTier => (is => 'ro', isa => 'Int');
  has PubliclyAccessible => (is => 'ro', isa => 'Bool');
  has StorageEncrypted => (is => 'ro', isa => 'Bool');
  has StorageType => (is => 'ro', isa => 'Str');
  has Tags => (is => 'ro', isa => 'ArrayRef[Paws::RDS::Tag]');
  has TdeCredentialArn => (is => 'ro', isa => 'Str');
  has TdeCredentialPassword => (is => 'ro', isa => 'Str');
  has Timezone => (is => 'ro', isa => 'Str');
  has VpcSecurityGroupIds => (is => 'ro', isa => 'ArrayRef[Str|Undef]');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CreateDBInstance');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::RDS::CreateDBInstanceResult');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'CreateDBInstanceResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::CreateDBInstance - Arguments for method CreateDBInstance on L<Paws::RDS>

=head1 DESCRIPTION

This class represents the parameters used for calling the method CreateDBInstance on the
L<Amazon Relational Database Service|Paws::RDS> service. Use the attributes of this class
as arguments to method CreateDBInstance.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to CreateDBInstance.

=head1 SYNOPSIS

    my $rds = Paws->service('RDS');
    # To create a DB instance.
    # This example creates a DB instance.
    my $CreateDBInstanceResult = $rds->CreateDBInstance(
      'AllocatedStorage'     => 5,
      'DBInstanceClass'      => 'db.t2.micro',
      'DBInstanceIdentifier' => 'mymysqlinstance',
      'Engine'               => 'MySQL',
      'MasterUserPassword'   => 'MyPassword',
      'MasterUsername'       => 'MyUser'
    );

    # Results:
    my $DBInstance = $CreateDBInstanceResult->DBInstance;

    # Returns a L<Paws::RDS::CreateDBInstanceResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/rds/CreateDBInstance>

=head1 ATTRIBUTES


=head2 AllocatedStorage => Int

The amount of storage (in gibibytes) to allocate for the DB instance.

Type: Integer

B<Amazon Aurora>

Not applicable. Aurora cluster volumes automatically grow as the amount
of data in your database increases, though you are only charged for the
space that you use in an Aurora cluster volume.

B<MySQL>

Constraints to the amount of storage for each storage type are the
following:

=over

=item *

General Purpose (SSD) storage (gp2): Must be an integer from 20 to
65536.

=item *

Provisioned IOPS storage (io1): Must be an integer from 100 to 65536.

=item *

Magnetic storage (standard): Must be an integer from 5 to 3072.

=back

B<MariaDB>

Constraints to the amount of storage for each storage type are the
following:

=over

=item *

General Purpose (SSD) storage (gp2): Must be an integer from 20 to
65536.

=item *

Provisioned IOPS storage (io1): Must be an integer from 100 to 65536.

=item *

Magnetic storage (standard): Must be an integer from 5 to 3072.

=back

B<PostgreSQL>

Constraints to the amount of storage for each storage type are the
following:

=over

=item *

General Purpose (SSD) storage (gp2): Must be an integer from 20 to
65536.

=item *

Provisioned IOPS storage (io1): Must be an integer from 100 to 65536.

=item *

Magnetic storage (standard): Must be an integer from 5 to 3072.

=back

B<Oracle>

Constraints to the amount of storage for each storage type are the
following:

=over

=item *

General Purpose (SSD) storage (gp2): Must be an integer from 20 to
65536.

=item *

Provisioned IOPS storage (io1): Must be an integer from 100 to 65536.

=item *

Magnetic storage (standard): Must be an integer from 10 to 3072.

=back

B<SQL Server>

Constraints to the amount of storage for each storage type are the
following:

=over

=item *

General Purpose (SSD) storage (gp2):

=over

=item *

Enterprise and Standard editions: Must be an integer from 200 to 16384.

=item *

Web and Express editions: Must be an integer from 20 to 16384.

=back

=item *

Provisioned IOPS storage (io1):

=over

=item *

Enterprise and Standard editions: Must be an integer from 200 to 16384.

=item *

Web and Express editions: Must be an integer from 100 to 16384.

=back

=item *

Magnetic storage (standard):

=over

=item *

Enterprise and Standard editions: Must be an integer from 200 to 1024.

=item *

Web and Express editions: Must be an integer from 20 to 1024.

=back

=back




=head2 AutoMinorVersionUpgrade => Bool

A value that indicates whether minor engine upgrades are applied
automatically to the DB instance during the maintenance window. By
default, minor engine upgrades are applied automatically.



=head2 AvailabilityZone => Str

The Availability Zone (AZ) where the database will be created. For
information on Amazon Web Services Regions and Availability Zones, see
Regions and Availability Zones
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Concepts.RegionsAndAvailabilityZones.html).

Default: A random, system-chosen Availability Zone in the endpoint's
Amazon Web Services Region.

Example: C<us-east-1d>

Constraint: The C<AvailabilityZone> parameter can't be specified if the
DB instance is a Multi-AZ deployment. The specified Availability Zone
must be in the same Amazon Web Services Region as the current endpoint.

If you're creating a DB instance in an RDS on VMware environment,
specify the identifier of the custom Availability Zone to create the DB
instance in.

For more information about RDS on VMware, see the RDS on VMware User
Guide.
(https://docs.aws.amazon.com/AmazonRDS/latest/RDSonVMwareUserGuide/rds-on-vmware.html)



=head2 BackupRetentionPeriod => Int

The number of days for which automated backups are retained. Setting
this parameter to a positive number enables backups. Setting this
parameter to 0 disables automated backups.

B<Amazon Aurora>

Not applicable. The retention period for automated backups is managed
by the DB cluster.

Default: 1

Constraints:

=over

=item *

Must be a value from 0 to 35

=item *

Can't be set to 0 if the DB instance is a source to read replicas

=back




=head2 CharacterSetName => Str

For supported engines, indicates that the DB instance should be
associated with the specified CharacterSet.

B<Amazon Aurora>

Not applicable. The character set is managed by the DB cluster. For
more information, see C<CreateDBCluster>.



=head2 CopyTagsToSnapshot => Bool

A value that indicates whether to copy tags from the DB instance to
snapshots of the DB instance. By default, tags are not copied.

B<Amazon Aurora>

Not applicable. Copying tags to snapshots is managed by the DB cluster.
Setting this value for an Aurora DB instance has no effect on the DB
cluster setting.



=head2 DBClusterIdentifier => Str

The identifier of the DB cluster that the instance will belong to.



=head2 B<REQUIRED> DBInstanceClass => Str

The compute and memory capacity of the DB instance, for example,
C<db.m4.large>. Not all DB instance classes are available in all Amazon
Web Services Regions, or for all database engines. For the full list of
DB instance classes, and availability for your engine, see DB Instance
Class
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Concepts.DBInstanceClass.html)
in the I<Amazon RDS User Guide.>



=head2 B<REQUIRED> DBInstanceIdentifier => Str

The DB instance identifier. This parameter is stored as a lowercase
string.

Constraints:

=over

=item *

Must contain from 1 to 63 letters, numbers, or hyphens.

=item *

First character must be a letter.

=item *

Can't end with a hyphen or contain two consecutive hyphens.

=back

Example: C<mydbinstance>



=head2 DBName => Str

The meaning of this parameter differs according to the database engine
you use.

B<MySQL>

The name of the database to create when the DB instance is created. If
this parameter isn't specified, no database is created in the DB
instance.

Constraints:

=over

=item *

Must contain 1 to 64 letters or numbers.

=item *

Must begin with a letter. Subsequent characters can be letters,
underscores, or digits (0-9).

=item *

Can't be a word reserved by the specified database engine

=back

B<MariaDB>

The name of the database to create when the DB instance is created. If
this parameter isn't specified, no database is created in the DB
instance.

Constraints:

=over

=item *

Must contain 1 to 64 letters or numbers.

=item *

Must begin with a letter. Subsequent characters can be letters,
underscores, or digits (0-9).

=item *

Can't be a word reserved by the specified database engine

=back

B<PostgreSQL>

The name of the database to create when the DB instance is created. If
this parameter isn't specified, a database named C<postgres> is created
in the DB instance.

Constraints:

=over

=item *

Must contain 1 to 63 letters, numbers, or underscores.

=item *

Must begin with a letter. Subsequent characters can be letters,
underscores, or digits (0-9).

=item *

Can't be a word reserved by the specified database engine

=back

B<Oracle>

The Oracle System ID (SID) of the created DB instance. If you specify
C<null>, the default value C<ORCL> is used. You can't specify the
string NULL, or any other reserved word, for C<DBName>.

Default: C<ORCL>

Constraints:

=over

=item *

Can't be longer than 8 characters

=back

B<SQL Server>

Not applicable. Must be null.

B<Amazon Aurora MySQL>

The name of the database to create when the primary DB instance of the
Aurora MySQL DB cluster is created. If this parameter isn't specified
for an Aurora MySQL DB cluster, no database is created in the DB
cluster.

Constraints:

=over

=item *

It must contain 1 to 64 alphanumeric characters.

=item *

It can't be a word reserved by the database engine.

=back

B<Amazon Aurora PostgreSQL>

The name of the database to create when the primary DB instance of the
Aurora PostgreSQL DB cluster is created. If this parameter isn't
specified for an Aurora PostgreSQL DB cluster, a database named
C<postgres> is created in the DB cluster.

Constraints:

=over

=item *

It must contain 1 to 63 alphanumeric characters.

=item *

It must begin with a letter or an underscore. Subsequent characters can
be letters, underscores, or digits (0 to 9).

=item *

It can't be a word reserved by the database engine.

=back




=head2 DBParameterGroupName => Str

The name of the DB parameter group to associate with this DB instance.
If you do not specify a value, then the default DB parameter group for
the specified DB engine and version is used.

Constraints:

=over

=item *

Must be 1 to 255 letters, numbers, or hyphens.

=item *

First character must be a letter

=item *

Can't end with a hyphen or contain two consecutive hyphens

=back




=head2 DBSecurityGroups => ArrayRef[Str|Undef]

A list of DB security groups to associate with this DB instance.

Default: The default DB security group for the database engine.



=head2 DBSubnetGroupName => Str

A DB subnet group to associate with this DB instance.

If there is no DB subnet group, then it is a non-VPC DB instance.



=head2 DeletionProtection => Bool

A value that indicates whether the DB instance has deletion protection
enabled. The database can't be deleted when deletion protection is
enabled. By default, deletion protection is disabled. For more
information, see Deleting a DB Instance
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_DeleteInstance.html).

B<Amazon Aurora>

Not applicable. You can enable or disable deletion protection for the
DB cluster. For more information, see C<CreateDBCluster>. DB instances
in a DB cluster can be deleted even when deletion protection is enabled
for the DB cluster.



=head2 Domain => Str

The Active Directory directory ID to create the DB instance in.
Currently, only MySQL, Microsoft SQL Server, Oracle, and PostgreSQL DB
instances can be created in an Active Directory Domain.

For more information, see Kerberos Authentication
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/kerberos-authentication.html)
in the I<Amazon RDS User Guide>.



=head2 DomainIAMRoleName => Str

Specify the name of the IAM role to be used when making API calls to
the Directory Service.



=head2 EnableCloudwatchLogsExports => ArrayRef[Str|Undef]

The list of log types that need to be enabled for exporting to
CloudWatch Logs. The values in the list depend on the DB engine being
used. For more information, see Publishing Database Logs to Amazon
CloudWatch Logs
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_LogAccess.html#USER_LogAccess.Procedural.UploadtoCloudWatch)
in the I<Amazon Relational Database Service User Guide>.

B<Amazon Aurora>

Not applicable. CloudWatch Logs exports are managed by the DB cluster.

B<MariaDB>

Possible values are C<audit>, C<error>, C<general>, and C<slowquery>.

B<Microsoft SQL Server>

Possible values are C<agent> and C<error>.

B<MySQL>

Possible values are C<audit>, C<error>, C<general>, and C<slowquery>.

B<Oracle>

Possible values are C<alert>, C<audit>, C<listener>, C<trace>, and
C<oemagent>.

B<PostgreSQL>

Possible values are C<postgresql> and C<upgrade>.



=head2 EnableCustomerOwnedIp => Bool

A value that indicates whether to enable a customer-owned IP address
(CoIP) for an RDS on Outposts DB instance.

A I<CoIP> provides local or external connectivity to resources in your
Outpost subnets through your on-premises network. For some use cases, a
CoIP can provide lower latency for connections to the DB instance from
outside of its virtual private cloud (VPC) on your local network.

For more information about RDS on Outposts, see Working with Amazon RDS
on Amazon Web Services Outposts
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/rds-on-outposts.html)
in the I<Amazon RDS User Guide>.

For more information about CoIPs, see Customer-owned IP addresses
(https://docs.aws.amazon.com/outposts/latest/userguide/outposts-networking-components.html#ip-addressing)
in the I<Amazon Web Services Outposts User Guide>.



=head2 EnableIAMDatabaseAuthentication => Bool

A value that indicates whether to enable mapping of Amazon Web Services
Identity and Access Management (IAM) accounts to database accounts. By
default, mapping is disabled.

This setting doesn't apply to Amazon Aurora. Mapping Amazon Web
Services IAM accounts to database accounts is managed by the DB
cluster.

For more information, see IAM Database Authentication for MySQL and
PostgreSQL
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.IAMDBAuth.html)
in the I<Amazon RDS User Guide.>



=head2 EnablePerformanceInsights => Bool

A value that indicates whether to enable Performance Insights for the
DB instance.

For more information, see Using Amazon Performance Insights
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_PerfInsights.html)
in the I<Amazon Relational Database Service User Guide>.



=head2 B<REQUIRED> Engine => Str

The name of the database engine to be used for this instance.

Not every database engine is available for every Amazon Web Services
Region.

Valid Values:

=over

=item *

C<aurora> (for MySQL 5.6-compatible Aurora)

=item *

C<aurora-mysql> (for MySQL 5.7-compatible Aurora)

=item *

C<aurora-postgresql>

=item *

C<mariadb>

=item *

C<mysql>

=item *

C<oracle-ee>

=item *

C<oracle-ee-cdb>

=item *

C<oracle-se2>

=item *

C<oracle-se2-cdb>

=item *

C<postgres>

=item *

C<sqlserver-ee>

=item *

C<sqlserver-se>

=item *

C<sqlserver-ex>

=item *

C<sqlserver-web>

=back




=head2 EngineVersion => Str

The version number of the database engine to use.

For a list of valid engine versions, use the
C<DescribeDBEngineVersions> action.

The following are the database engines and links to information about
the major and minor versions that are available with Amazon RDS. Not
every database engine is available for every Amazon Web Services
Region.

B<Amazon Aurora>

Not applicable. The version number of the database engine to be used by
the DB instance is managed by the DB cluster.

B<MariaDB>

See MariaDB on Amazon RDS Versions
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/CHAP_MariaDB.html#MariaDB.Concepts.VersionMgmt)
in the I<Amazon RDS User Guide.>

B<Microsoft SQL Server>

See Microsoft SQL Server Versions on Amazon RDS
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/CHAP_SQLServer.html#SQLServer.Concepts.General.VersionSupport)
in the I<Amazon RDS User Guide.>

B<MySQL>

See MySQL on Amazon RDS Versions
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/CHAP_MySQL.html#MySQL.Concepts.VersionMgmt)
in the I<Amazon RDS User Guide.>

B<Oracle>

See Oracle Database Engine Release Notes
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Appendix.Oracle.PatchComposition.html)
in the I<Amazon RDS User Guide.>

B<PostgreSQL>

See Amazon RDS for PostgreSQL versions and extensions
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/CHAP_PostgreSQL.html#PostgreSQL.Concepts)
in the I<Amazon RDS User Guide.>



=head2 Iops => Int

The amount of Provisioned IOPS (input/output operations per second) to
be initially allocated for the DB instance. For information about valid
Iops values, see Amazon RDS Provisioned IOPS Storage to Improve
Performance
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/CHAP_Storage.html#USER_PIOPS)
in the I<Amazon RDS User Guide>.

Constraints: For MariaDB, MySQL, Oracle, and PostgreSQL DB instances,
must be a multiple between .5 and 50 of the storage amount for the DB
instance. For SQL Server DB instances, must be a multiple between 1 and
50 of the storage amount for the DB instance.



=head2 KmsKeyId => Str

The Amazon Web Services KMS key identifier for an encrypted DB
instance.

The Amazon Web Services KMS key identifier is the key ARN, key ID,
alias ARN, or alias name for the Amazon Web Services KMS customer
master key (CMK). To use a CMK in a different Amazon Web Services
account, specify the key ARN or alias ARN.

B<Amazon Aurora>

Not applicable. The Amazon Web Services KMS key identifier is managed
by the DB cluster. For more information, see C<CreateDBCluster>.

If C<StorageEncrypted> is enabled, and you do not specify a value for
the C<KmsKeyId> parameter, then Amazon RDS uses your default CMK. There
is a default CMK for your Amazon Web Services account. Your Amazon Web
Services account has a different default CMK for each Amazon Web
Services Region.



=head2 LicenseModel => Str

License model information for this DB instance.

Valid values: C<license-included> | C<bring-your-own-license> |
C<general-public-license>



=head2 MasterUsername => Str

The name for the master user.

B<Amazon Aurora>

Not applicable. The name for the master user is managed by the DB
cluster.

B<MariaDB>

Constraints:

=over

=item *

Required for MariaDB.

=item *

Must be 1 to 16 letters or numbers.

=item *

Can't be a reserved word for the chosen database engine.

=back

B<Microsoft SQL Server>

Constraints:

=over

=item *

Required for SQL Server.

=item *

Must be 1 to 128 letters or numbers.

=item *

The first character must be a letter.

=item *

Can't be a reserved word for the chosen database engine.

=back

B<MySQL>

Constraints:

=over

=item *

Required for MySQL.

=item *

Must be 1 to 16 letters or numbers.

=item *

First character must be a letter.

=item *

Can't be a reserved word for the chosen database engine.

=back

B<Oracle>

Constraints:

=over

=item *

Required for Oracle.

=item *

Must be 1 to 30 letters or numbers.

=item *

First character must be a letter.

=item *

Can't be a reserved word for the chosen database engine.

=back

B<PostgreSQL>

Constraints:

=over

=item *

Required for PostgreSQL.

=item *

Must be 1 to 63 letters or numbers.

=item *

First character must be a letter.

=item *

Can't be a reserved word for the chosen database engine.

=back




=head2 MasterUserPassword => Str

The password for the master user. The password can include any
printable ASCII character except "/", """, or "@".

B<Amazon Aurora>

Not applicable. The password for the master user is managed by the DB
cluster.

B<MariaDB>

Constraints: Must contain from 8 to 41 characters.

B<Microsoft SQL Server>

Constraints: Must contain from 8 to 128 characters.

B<MySQL>

Constraints: Must contain from 8 to 41 characters.

B<Oracle>

Constraints: Must contain from 8 to 30 characters.

B<PostgreSQL>

Constraints: Must contain from 8 to 128 characters.



=head2 MaxAllocatedStorage => Int

The upper limit to which Amazon RDS can automatically scale the storage
of the DB instance.

For more information about this setting, including limitations that
apply to it, see Managing capacity automatically with Amazon RDS
storage autoscaling
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_PIOPS.StorageTypes.html#USER_PIOPS.Autoscaling)
in the I<Amazon RDS User Guide>.



=head2 MonitoringInterval => Int

The interval, in seconds, between points when Enhanced Monitoring
metrics are collected for the DB instance. To disable collecting
Enhanced Monitoring metrics, specify 0. The default is 0.

If C<MonitoringRoleArn> is specified, then you must also set
C<MonitoringInterval> to a value other than 0.

Valid Values: C<0, 1, 5, 10, 15, 30, 60>



=head2 MonitoringRoleArn => Str

The ARN for the IAM role that permits RDS to send enhanced monitoring
metrics to Amazon CloudWatch Logs. For example,
C<arn:aws:iam:123456789012:role/emaccess>. For information on creating
a monitoring role, go to Setting Up and Enabling Enhanced Monitoring
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Monitoring.OS.html#USER_Monitoring.OS.Enabling)
in the I<Amazon RDS User Guide>.

If C<MonitoringInterval> is set to a value other than 0, then you must
supply a C<MonitoringRoleArn> value.



=head2 MultiAZ => Bool

A value that indicates whether the DB instance is a Multi-AZ
deployment. You can't set the C<AvailabilityZone> parameter if the DB
instance is a Multi-AZ deployment.



=head2 NcharCharacterSetName => Str

The name of the NCHAR character set for the Oracle DB instance.



=head2 OptionGroupName => Str

A value that indicates that the DB instance should be associated with
the specified option group.

Permanent options, such as the TDE option for Oracle Advanced Security
TDE, can't be removed from an option group. Also, that option group
can't be removed from a DB instance once it is associated with a DB
instance



=head2 PerformanceInsightsKMSKeyId => Str

The Amazon Web Services KMS key identifier for encryption of
Performance Insights data.

The Amazon Web Services KMS key identifier is the key ARN, key ID,
alias ARN, or alias name for the Amazon Web Services KMS customer
master key (CMK).

If you do not specify a value for C<PerformanceInsightsKMSKeyId>, then
Amazon RDS uses your default CMK. There is a default CMK for your
Amazon Web Services account. Your Amazon Web Services account has a
different default CMK for each Amazon Web Services Region.



=head2 PerformanceInsightsRetentionPeriod => Int

The amount of time, in days, to retain Performance Insights data. Valid
values are 7 or 731 (2 years).



=head2 Port => Int

The port number on which the database accepts connections.

B<MySQL>

Default: C<3306>

Valid values: C<1150-65535>

Type: Integer

B<MariaDB>

Default: C<3306>

Valid values: C<1150-65535>

Type: Integer

B<PostgreSQL>

Default: C<5432>

Valid values: C<1150-65535>

Type: Integer

B<Oracle>

Default: C<1521>

Valid values: C<1150-65535>

B<SQL Server>

Default: C<1433>

Valid values: C<1150-65535> except C<1234>, C<1434>, C<3260>, C<3343>,
C<3389>, C<47001>, and C<49152-49156>.

B<Amazon Aurora>

Default: C<3306>

Valid values: C<1150-65535>

Type: Integer



=head2 PreferredBackupWindow => Str

The daily time range during which automated backups are created if
automated backups are enabled, using the C<BackupRetentionPeriod>
parameter. The default is a 30-minute window selected at random from an
8-hour block of time for each Amazon Web Services Region. For more
information, see Backup window
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_WorkingWithAutomatedBackups.html#USER_WorkingWithAutomatedBackups.BackupWindow)
in the I<Amazon RDS User Guide>.

B<Amazon Aurora>

Not applicable. The daily time range for creating automated backups is
managed by the DB cluster.

Constraints:

=over

=item *

Must be in the format C<hh24:mi-hh24:mi>.

=item *

Must be in Universal Coordinated Time (UTC).

=item *

Must not conflict with the preferred maintenance window.

=item *

Must be at least 30 minutes.

=back




=head2 PreferredMaintenanceWindow => Str

The time range each week during which system maintenance can occur, in
Universal Coordinated Time (UTC). For more information, see Amazon RDS
Maintenance Window
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_UpgradeDBInstance.Maintenance.html#Concepts.DBMaintenance).

Format: C<ddd:hh24:mi-ddd:hh24:mi>

The default is a 30-minute window selected at random from an 8-hour
block of time for each Amazon Web Services Region, occurring on a
random day of the week.

Valid Days: Mon, Tue, Wed, Thu, Fri, Sat, Sun.

Constraints: Minimum 30-minute window.



=head2 ProcessorFeatures => ArrayRef[L<Paws::RDS::ProcessorFeature>]

The number of CPU cores and the number of threads per core for the DB
instance class of the DB instance.



=head2 PromotionTier => Int

A value that specifies the order in which an Aurora Replica is promoted
to the primary instance after a failure of the existing primary
instance. For more information, see Fault Tolerance for an Aurora DB
Cluster
(https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/Aurora.Managing.Backups.html#Aurora.Managing.FaultTolerance)
in the I<Amazon Aurora User Guide>.

Default: 1

Valid Values: 0 - 15



=head2 PubliclyAccessible => Bool

A value that indicates whether the DB instance is publicly accessible.

When the DB instance is publicly accessible, its DNS endpoint resolves
to the private IP address from within the DB instance's VPC, and to the
public IP address from outside of the DB instance's VPC. Access to the
DB instance is ultimately controlled by the security group it uses, and
that public access is not permitted if the security group assigned to
the DB instance doesn't permit it.

When the DB instance isn't publicly accessible, it is an internal DB
instance with a DNS name that resolves to a private IP address.

Default: The default behavior varies depending on whether
C<DBSubnetGroupName> is specified.

If C<DBSubnetGroupName> isn't specified, and C<PubliclyAccessible>
isn't specified, the following applies:

=over

=item *

If the default VPC in the target region doesnE<rsquo>t have an Internet
gateway attached to it, the DB instance is private.

=item *

If the default VPC in the target region has an Internet gateway
attached to it, the DB instance is public.

=back

If C<DBSubnetGroupName> is specified, and C<PubliclyAccessible> isn't
specified, the following applies:

=over

=item *

If the subnets are part of a VPC that doesnE<rsquo>t have an Internet
gateway attached to it, the DB instance is private.

=item *

If the subnets are part of a VPC that has an Internet gateway attached
to it, the DB instance is public.

=back




=head2 StorageEncrypted => Bool

A value that indicates whether the DB instance is encrypted. By
default, it isn't encrypted.

B<Amazon Aurora>

Not applicable. The encryption for DB instances is managed by the DB
cluster.



=head2 StorageType => Str

Specifies the storage type to be associated with the DB instance.

Valid values: C<standard | gp2 | io1>

If you specify C<io1>, you must also include a value for the C<Iops>
parameter.

Default: C<io1> if the C<Iops> parameter is specified, otherwise C<gp2>



=head2 Tags => ArrayRef[L<Paws::RDS::Tag>]

Tags to assign to the DB instance.



=head2 TdeCredentialArn => Str

The ARN from the key store with which to associate the instance for TDE
encryption.



=head2 TdeCredentialPassword => Str

The password for the given ARN from the key store in order to access
the device.



=head2 Timezone => Str

The time zone of the DB instance. The time zone parameter is currently
supported only by Microsoft SQL Server
(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/CHAP_SQLServer.html#SQLServer.Concepts.General.TimeZone).



=head2 VpcSecurityGroupIds => ArrayRef[Str|Undef]

A list of Amazon EC2 VPC security groups to associate with this DB
instance.

B<Amazon Aurora>

Not applicable. The associated list of EC2 VPC security groups is
managed by the DB cluster.

Default: The default EC2 VPC security group for the DB subnet group's
VPC.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CreateDBInstance in L<Paws::RDS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

