
package Paws::Route53Domains::TransferDomainToAnotherAwsAccount;
  use Moose;
  has AccountId => (is => 'ro', isa => 'Str', required => 1);
  has DomainName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'TransferDomainToAnotherAwsAccount');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Route53Domains::TransferDomainToAnotherAwsAccountResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Route53Domains::TransferDomainToAnotherAwsAccount - Arguments for method TransferDomainToAnotherAwsAccount on L<Paws::Route53Domains>

=head1 DESCRIPTION

This class represents the parameters used for calling the method TransferDomainToAnotherAwsAccount on the
L<Amazon Route 53 Domains|Paws::Route53Domains> service. Use the attributes of this class
as arguments to method TransferDomainToAnotherAwsAccount.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to TransferDomainToAnotherAwsAccount.

=head1 SYNOPSIS

    my $route53domains = Paws->service('Route53Domains');
    my $TransferDomainToAnotherAwsAccountResponse =
      $route53domains->TransferDomainToAnotherAwsAccount(
      AccountId  => 'MyAccountId',
      DomainName => 'MyDomainName',

      );

    # Results:
    my $OperationId = $TransferDomainToAnotherAwsAccountResponse->OperationId;
    my $Password    = $TransferDomainToAnotherAwsAccountResponse->Password;

# Returns a L<Paws::Route53Domains::TransferDomainToAnotherAwsAccountResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/route53domains/TransferDomainToAnotherAwsAccount>

=head1 ATTRIBUTES


=head2 B<REQUIRED> AccountId => Str

The account ID of the AWS account that you want to transfer the domain
to, for example, C<111122223333>.



=head2 B<REQUIRED> DomainName => Str

The name of the domain that you want to transfer from the current AWS
account to another account.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method TransferDomainToAnotherAwsAccount in L<Paws::Route53Domains>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

