
package Paws::SageMaker::DescribeContext;
  use Moose;
  has ContextName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeContext');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SageMaker::DescribeContextResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SageMaker::DescribeContext - Arguments for method DescribeContext on L<Paws::SageMaker>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeContext on the
L<Amazon SageMaker Service|Paws::SageMaker> service. Use the attributes of this class
as arguments to method DescribeContext.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeContext.

=head1 SYNOPSIS

    my $api.sagemaker = Paws->service('SageMaker');
    my $DescribeContextResponse = $api . sagemaker->DescribeContext(
      ContextName => 'MyExperimentEntityName',

    );

    # Results:
    my $ContextArn       = $DescribeContextResponse->ContextArn;
    my $ContextName      = $DescribeContextResponse->ContextName;
    my $ContextType      = $DescribeContextResponse->ContextType;
    my $CreatedBy        = $DescribeContextResponse->CreatedBy;
    my $CreationTime     = $DescribeContextResponse->CreationTime;
    my $Description      = $DescribeContextResponse->Description;
    my $LastModifiedBy   = $DescribeContextResponse->LastModifiedBy;
    my $LastModifiedTime = $DescribeContextResponse->LastModifiedTime;
    my $Properties       = $DescribeContextResponse->Properties;
    my $Source           = $DescribeContextResponse->Source;

    # Returns a L<Paws::SageMaker::DescribeContextResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/api.sagemaker/DescribeContext>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ContextName => Str

The name of the context to describe.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeContext in L<Paws::SageMaker>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

