
package Paws::StorageGateway::DeleteBandwidthRateLimit;
  use Moose;
  has BandwidthType => (is => 'ro', isa => 'Str', required => 1);
  has GatewayARN => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteBandwidthRateLimit');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::StorageGateway::DeleteBandwidthRateLimitOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::StorageGateway::DeleteBandwidthRateLimit - Arguments for method DeleteBandwidthRateLimit on L<Paws::StorageGateway>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteBandwidthRateLimit on the
L<AWS Storage Gateway|Paws::StorageGateway> service. Use the attributes of this class
as arguments to method DeleteBandwidthRateLimit.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteBandwidthRateLimit.

=head1 SYNOPSIS

    my $storagegateway = Paws->service('StorageGateway');
 # To delete bandwidth rate limits of gateway
 # Deletes the bandwidth rate limits of a gateway; either the upload or download
 # limit, or both.
    my $DeleteBandwidthRateLimitOutput =
      $storagegateway->DeleteBandwidthRateLimit(
      'BandwidthType' => 'All',
      'GatewayARN'    =>
        'arn:aws:storagegateway:us-east-1:111122223333:gateway/sgw-12A3456B'
      );

    # Results:
    my $GatewayARN = $DeleteBandwidthRateLimitOutput->GatewayARN;

    # Returns a L<Paws::StorageGateway::DeleteBandwidthRateLimitOutput> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/storagegateway/DeleteBandwidthRateLimit>

=head1 ATTRIBUTES


=head2 B<REQUIRED> BandwidthType => Str

One of the BandwidthType values that indicates the gateway bandwidth
rate limit to delete.

Valid Values: C<UPLOAD> | C<DOWNLOAD> | C<ALL>



=head2 B<REQUIRED> GatewayARN => Str






=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteBandwidthRateLimit in L<Paws::StorageGateway>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

